@@ -3,7 +3,7 @@ package Alien::OpenSSL;
 use strict;
 use warnings;
 
-our $VERSION = '0.10_3';
+our $VERSION = '0.01';
 
 use parent 'Alien::Base';
 
@@ -13,7 +13,7 @@ __END__
 
 =head1 NAME
 
-Alien::OpenSSL - Alien wrapper for OpenSSL
+Acme::NSS - Alien wrapper for OpenSSL
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,3 @@ Alien wrapper for OpenSSL
 
 This library provides an alien wrapper for OpenSSL.
 
-=head1 SEE ALSO
-
-OpenSSL(1), Crypt::OpenSSL::X509, Alien::Base
-
